## Amy Tanner: 25/11/2016. This R code corresponds to the analysis in: 
## Tanner AL, Leroux SJ, and Saunders PW. [submitted]. Road Characteristics Best Predict the Probability of Vehicle Collisions with a Non-native Ungulate.

## Clear the workspace
rm(list=ls(all=TRUE))

## New dataset required
## Import your mvc data file and fullspatialrandompts files
spatialallrandom<-read.csv("spatialallrandom.csv")
spatialallmvc<-read.csv("spatialallmvc.csv")

## Make some empty tables to populate with AIC data during the model loop below.
LinearDist<-NULL 
Water<-NULL 
Terrain<-NULL
Road<-NULL
Mitigation<-NULL
MooseDen<-NULL
LinearDens<-NULL
VegComp<-NULL
Biotic<-NULL
Physical<-NULL
Human<-NULL
Linear<-NULL
BioPhys<-NULL
HumanLinear<-NULL
Intercept<-NULL

## Make empty table for each model (n = 14). We should probably add an intercept only model too. So n =15.
for(i in seq(1,100,1)){
  ## Step 1: Select random set 
  Random_Pts<-NULL 
  ## Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for MVCs.
  ## This is where you take 600 points from the 1200. 
  Random_Pts <- spatialallrandom[sample(nrow(spatialallrandom), 600),] 
  ## Step 2: Combine the data 
  ## Combine with presence data to make file for model fitting 
  PresAvailSet <- rbind(Random_Pts, spatialallmvc) 
  ## Step 3: Fit the models #AIC table for glm models 
  library(AICcmodavg)
  Cand.models <- list( ) 
  Cand.models[[1]] <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[2]] <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[3]] <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[4]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[5]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[6]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[7]] <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[8]] <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[9]] <- glm(Rand_MVC~MooseDen + PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[10]] <- glm(Rand_MVC~TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[11]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[12]] <- glm(Rand_MVC~DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[13]] <- glm(Rand_MVC~MooseDen + PropDecidConif5471 + TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[14]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc + DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[15]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  ## Create a vector of names to trace back models in set 
  Modnames <- c("1", "2", "3","4","5","6","7","8","9","10","11","12","13","14","15")
  ## Generate AICc table 
  AICTable <- aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE, digits = 4, LL = TRUE) 
  
  library(fmsb)
  LinearDist_Model <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  WaterFeat_Model <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Terrain_Model <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Road_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Mitigation_Model <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  MooseDensity_Model <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  LinearDen_Model <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Comp5471_Model <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Biotic_Model <- glm(Rand_MVC~MooseDen + PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Physical_Model <- glm(Rand_MVC~TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Human_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Linear_Model <- glm(Rand_MVC~DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  BioPhys_Model <- glm(Rand_MVC~MooseDen + PropDecidConif5471 + TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  HumTrav_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc + DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Null_Model <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  
  ## Step 4: Collect the data in a table for each model 
  LinearDist <- rbind(LinearDist, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="1"], LogLik=AICTable$LL[AICTable$Modnames=="1"], NagR2=NagelkerkeR2(LinearDist_Model)$R2)) 
  Water <- rbind(Water, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="2"], LogLik=AICTable$LL[AICTable$Modnames=="2"], NagR2=NagelkerkeR2(WaterFeat_Model)$R2)) 
  Terrain <- rbind(Terrain, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="3"], LogLik=AICTable$LL[AICTable$Modnames=="3"], NagR2=NagelkerkeR2(Terrain_Model)$R2)) 
  Road <- rbind(Road, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="4"], LogLik=AICTable$LL[AICTable$Modnames=="4"], NagR2=NagelkerkeR2(Road_Model)$R2)) 
  Mitigation <- rbind(Mitigation, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="5"], LogLik=AICTable$LL[AICTable$Modnames=="5"], NagR2=NagelkerkeR2(Mitigation_Model)$R2)) 
  MooseDen <- rbind(MooseDen, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="6"], LogLik=AICTable$LL[AICTable$Modnames=="6"], NagR2=NagelkerkeR2(MooseDensity_Model)$R2)) 
  LinearDens <- rbind(LinearDens, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="7"], LogLik=AICTable$LL[AICTable$Modnames=="7"], NagR2=NagelkerkeR2(LinearDen_Model)$R2)) 
  VegComp <- rbind(VegComp, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="8"], LogLik=AICTable$LL[AICTable$Modnames=="8"], NagR2=NagelkerkeR2(Comp5471_Model)$R2)) 
  Biotic <- rbind(Biotic, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="9"], LogLik=AICTable$LL[AICTable$Modnames=="9"], NagR2=NagelkerkeR2(Biotic_Model)$R2)) 
  Physical <- rbind(Physical, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="10"], LogLik=AICTable$LL[AICTable$Modnames=="10"], NagR2=NagelkerkeR2(Physical_Model)$R2)) 
  Human <- rbind(Human, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="11"], LogLik=AICTable$LL[AICTable$Modnames=="11"], NagR2=NagelkerkeR2(Human_Model)$R2)) 
  Linear <- rbind(Linear, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="12"], LogLik=AICTable$LL[AICTable$Modnames=="12"], NagR2=NagelkerkeR2(Linear_Model)$R2)) 
  BioPhys <- rbind(BioPhys, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="13"], LogLik=AICTable$LL[AICTable$Modnames=="13"], NagR2=NagelkerkeR2(BioPhys_Model)$R2)) 
  HumanLinear <- rbind(HumanLinear, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="14"], LogLik=AICTable$LL[AICTable$Modnames=="14"], NagR2=NagelkerkeR2(HumTrav_Model)$R2)) 
  Intercept <- rbind(Intercept, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="15"], LogLik=AICTable$LL[AICTable$Modnames=="15"], NagR2=NagelkerkeR2(Null_Model)$R2)) 
  print(i) 
} 

## Process simulation data. I want to know the number of times each models is top model, so deltaAICc = 0.00000000 and number of times the model is AIC < 2 of top model. 
## AIC summary results 
Summary <- NULL 
Summary <- rbind(Summary, data.frame(Rank=c("top","<2", "MeanNagR2"), LinearDist=c(sum(LinearDist$Delta_AICc==0.00000000),sum(LinearDist$Delta_AICc<2.0), mean(LinearDist$NagR2)), Water=c(sum(Water$Delta_AICc==0.00000000),sum(Water$Delta_AICc<2.0), mean(Water$NagR2)),Terrain=c(sum(Terrain$Delta_AICc==0.00000000),sum(Terrain$Delta_AICc<2.0), mean(Terrain$NagR2)), Road=c(sum(Road$Delta_AICc==0.00000000),sum(Road$Delta_AICc<2.0), mean(Road$NagR2)), Mitigation=c(sum(Mitigation$Delta_AICc==0.00000000),sum(Mitigation$Delta_AICc<2.0), mean(Mitigation$NagR2)), MooseDen=c(sum(MooseDen$Delta_AICc==0.00000000),sum(MooseDen$Delta_AICc<2.0), mean(MooseDen$NagR2)), LinearDens=c(sum(LinearDens$Delta_AICc==0.00000000),sum(LinearDens$Delta_AICc<2.0), mean(LinearDens$NagR2)),VegComp=c(sum(VegComp$Delta_AICc==0.00000000),sum(VegComp$Delta_AICc<2.0), mean(VegComp$NagR2)),Biotic=c(sum(Biotic$Delta_AICc==0.00000000),sum(Biotic$Delta_AICc<2.0), mean(Biotic$NagR2)),Physical=c(sum(Physical$Delta_AICc==0.00000000),sum(Physical$Delta_AICc<2.0), mean(Physical$NagR2)),Human=c(sum(Human$Delta_AICc==0.00000000),sum(Human$Delta_AICc<2.0), mean(Human$NagR2)), Linear=c(sum(Linear$Delta_AICc==0.00000000),sum(Linear$Delta_AICc<2.0), mean(Linear$NagR2)), BioPhys=c(sum(BioPhys$Delta_AICc==0.00000000),sum(BioPhys$Delta_AICc<2.0), mean(BioPhys$NagR2)), HumanLinear=c(sum(HumanLinear$Delta_AICc==0.00000000),sum(HumanLinear$Delta_AICc<2.0), mean(HumanLinear$NagR2)), Intercept=c(sum(Intercept$Delta_AICc==0.00000000),sum(Intercept$Delta_AICc<2.0), mean(Intercept$NagR2))))
print(Summary)

##################################################
## Reduced model set
## Dataset is the data after the pretending variables were removed: pretending variable if the delta AIC value is ~ 2, 
## when adding the variable the deviance doesn't change, parameter estimates ~0 with large confidence intervals. 
## For more information: https://theartofmodelling.wordpress.com/2012/04/01/getting-the-most-information-from-your-models-6-keys-to-model-selection/

## Make some empty tables to populate with AIC data during the model loop below.
LinearDist<-NULL 
Water<-NULL 
Terrain<-NULL
Road<-NULL
Mitigation<-NULL
MooseDen<-NULL
LinearDens<-NULL
VegComp<-NULL
Biotic<-NULL
Physical<-NULL
Human<-NULL
Linear<-NULL
BioPhys<-NULL
HumanLinear<-NULL
Intercept<-NULL
## Make empty table for each model (n = 11). We should probably add an intercept only model too. So n =12.
for(i in seq(1,100,1)){
  ## Step 1: Select random set 
  Random_Pts<-NULL 
  ## Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for MVCs.
  ## This is where you take 600 points from the 1200. 
  Random_Pts <- spatialallrandom[sample(nrow(spatialallrandom), 600),] 
  ## Step 2: Combine the data #Combine with presence data to make file for model fitting 
  PresAvailSet <- rbind(Random_Pts, spatialallmvc) 
  ## Step 3: Fit the models #AIC table for glm models 
  library(AICcmodavg)
  Cand.models <- list( ) 
  Cand.models[[1]] <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[2]] <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[3]] <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[4]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[5]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[6]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[7]] <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[8]] <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[9]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[10]] <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m + MooseDen, family=binomial(link="logit"), data=PresAvailSet)
  Cand.models[[11]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet)
  Cand.models[[12]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  ## Create a vector of names to trace back models in set 
  Modnames <- c("1", "2", "3","4","5","6","7","8","9","10","11","12")
  ## Generate AICc table 
  AICTable <- aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE, digits = 4, LL = TRUE) 
  print(AICTable)
  
  library(fmsb)
  LinearDist_Model <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  WaterFeat_Model <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Terrain_Model <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Road_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Mitigation_Model <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  MooseDensity_Model <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  LinearDen_Model <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Comp5471_Model <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Human_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  BioPhys_Model <- glm(Rand_MVC~MooseDen + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  HumTrav_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Null_Model <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  
  ## Step 4: Collect the data in a table for each model 
  LinearDist <- rbind(LinearDist, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="1"], LogLik=AICTable$LL[AICTable$Modnames=="1"], NagR2=NagelkerkeR2(LinearDist_Model)$R2)) 
  Water <- rbind(Water, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="2"], LogLik=AICTable$LL[AICTable$Modnames=="2"], NagR2=NagelkerkeR2(WaterFeat_Model)$R2)) 
  Terrain <- rbind(Terrain, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="3"], LogLik=AICTable$LL[AICTable$Modnames=="3"], NagR2=NagelkerkeR2(Terrain_Model)$R2)) 
  Road <- rbind(Road, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="4"], LogLik=AICTable$LL[AICTable$Modnames=="4"], NagR2=NagelkerkeR2(Road_Model)$R2)) 
  Mitigation <- rbind(Mitigation, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="5"], LogLik=AICTable$LL[AICTable$Modnames=="5"], NagR2=NagelkerkeR2(Mitigation_Model)$R2)) 
  MooseDen <- rbind(MooseDen, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="6"], LogLik=AICTable$LL[AICTable$Modnames=="6"], NagR2=NagelkerkeR2(MooseDensity_Model)$R2)) 
  LinearDens <- rbind(LinearDens, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="7"], LogLik=AICTable$LL[AICTable$Modnames=="7"], NagR2=NagelkerkeR2(LinearDen_Model)$R2)) 
  VegComp <- rbind(VegComp, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="8"], LogLik=AICTable$LL[AICTable$Modnames=="8"], NagR2=NagelkerkeR2(Comp5471_Model)$R2)) 
  Human <- rbind(Human, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="9"], LogLik=AICTable$LL[AICTable$Modnames=="9"], NagR2=NagelkerkeR2(Human_Model)$R2)) 
  BioPhys <- rbind(BioPhys, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="10"], LogLik=AICTable$LL[AICTable$Modnames=="10"], NagR2=NagelkerkeR2(BioPhys_Model)$R2)) 
  HumanLinear <- rbind(HumanLinear, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="11"], LogLik=AICTable$LL[AICTable$Modnames=="11"], NagR2=NagelkerkeR2(HumTrav_Model)$R2)) 
  Intercept <- rbind(Intercept, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="12"], LogLik=AICTable$LL[AICTable$Modnames=="12"], NagR2=NagelkerkeR2(Null_Model)$R2)) 
  print(i) 
} 

## Process simulation data. I want to know the number of times each models is top model, so deltaAICc = 0.00000000 and number of times the model is AIC < 2 of top model. 
## AIC summary results 
Summary <- NULL 
Summary <- rbind(Summary, data.frame(Rank=c("top","<2", "MeanNagR2"), LinearDist=c(sum(LinearDist$Delta_AICc==0.00000000),sum(LinearDist$Delta_AICc<2.0), mean(LinearDist$NagR2)), Water=c(sum(Water$Delta_AICc==0.00000000),sum(Water$Delta_AICc<2.0), mean(Water$NagR2)),Terrain=c(sum(Terrain$Delta_AICc==0.00000000),sum(Terrain$Delta_AICc<2.0), mean(Terrain$NagR2)), Road=c(sum(Road$Delta_AICc==0.00000000),sum(Road$Delta_AICc<2.0), mean(Road$NagR2)), Mitigation=c(sum(Mitigation$Delta_AICc==0.00000000),sum(Mitigation$Delta_AICc<2.0), mean(Mitigation$NagR2)), MooseDen=c(sum(MooseDen$Delta_AICc==0.00000000),sum(MooseDen$Delta_AICc<2.0), mean(MooseDen$NagR2)), LinearDens=c(sum(LinearDens$Delta_AICc==0.00000000),sum(LinearDens$Delta_AICc<2.0), mean(LinearDens$NagR2)),VegComp=c(sum(VegComp$Delta_AICc==0.00000000),sum(VegComp$Delta_AICc<2.0), mean(VegComp$NagR2)), Human=c(sum(Human$Delta_AICc==0.00000000),sum(Human$Delta_AICc<2.0), mean(Human$NagR2)), BioPhys=c(sum(BioPhys$Delta_AICc==0.00000000),sum(BioPhys$Delta_AICc<2.0), mean(BioPhys$NagR2)), HumanLinear=c(sum(HumanLinear$Delta_AICc==0.00000000),sum(HumanLinear$Delta_AICc<2.0), mean(HumanLinear$NagR2)), Intercept=c(sum(Intercept$Delta_AICc==0.00000000),sum(Intercept$Delta_AICc<2.0), mean(Intercept$NagR2))))
print(Summary)

##################################################
## Reduced model set #2
## Dataset is the data after the pretending variables were removed: pretending variable if the delta AIC value is ~ 2, 
## when adding the variable the deviance doesn't change, parameter estimates ~0 with large confidence intervals. 
## For more information: https://theartofmodelling.wordpress.com/2012/04/01/getting-the-most-information-from-your-models-6-keys-to-model-selection/

## Make some empty tables to populate with AIC data during the model loop below.
LinearDist<-NULL 
Water<-NULL 
Terrain<-NULL
Road<-NULL
Mitigation<-NULL
MooseDen<-NULL
LinearDens<-NULL
VegComp<-NULL
Human<-NULL
BioPhys<-NULL
Intercept<-NULL

GLM_HUMAN_Intercept <- NULL
GLM_HUMAN_RdClassSEC <- NULL
GLM_HUMAN_Sinuosity <- NULL
GLM_HUMAN_DisDev_m <- NULL
GLM_HUMAN_VegCutLocYES <- NULL
GLM_HUMAN_TABLE <- NULL

## Determining multicolinearity of variables
PresAvailSetBasic <- rbind(spatialallrandom, spatialallmvc)
library(car)
vif(glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~PropWater5471 + PropDevBare5471 + PropGrassShrub5471, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~MooseDen + PropWater5471 + PropDevBare5471 + PropGrassShrub5471, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~MooseDen + PropWater5471 + PropDevBare5471 + PropGrassShrub5471 + TerrRugg5471 + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSetBasic))
vif(glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc + DisLinFeaShort_m + DenLinFea5471, family=binomial(link="logit"), data=PresAvailSetBasic))

## Make empty table for each model (n = 10). We should probably add an intercept only model too. So n =11.
for(i in seq(1,100,1)){
  ## Step 1: Select random set 
  Random_Pts<-NULL 
  ## Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for that moose.
  ## This is where you take 600 points from the 1200. 
  Random_Pts <- spatialallrandom[sample(nrow(spatialallrandom), 600),] 
  ## Step 2: Combine the data 
  ## Combine with presence data to make file for model fitting 
  PresAvailSet <- rbind(Random_Pts, spatialallmvc) 
  ## Step 3: Fit the models #AIC table for glm models 
  library(AICcmodavg)
  Cand.models <- list( ) 
  Cand.models[[1]] <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[2]] <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[3]] <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[4]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[5]] <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[6]] <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[7]] <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[8]] <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[9]] <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[10]] <- glm(Rand_MVC~MooseDen + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Cand.models[[11]] <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  ## Create a vector of names to trace back models in set 
  Modnames <- c("1", "2", "3","4","5","6","7","8","9","10","11")
  ## Generate AICc table 
  AICTable <- aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE, digits = 4, LL = TRUE) 
  print(AICTable)
  
  library(fmsb)
  LinearDist_Model <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  WaterFeat_Model <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Terrain_Model <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
  Road_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
  Mitigation_Model <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  MooseDensity_Model <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
  LinearDens_Model <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
  Comp5471_Model <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
  Human_Model <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
  BioPhys_Model <- glm(Rand_MVC~MooseDen + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
  Null_Model <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
  
  ## Step 4: Collect the data in a table for each model 
  LinearDist <- rbind(LinearDist, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="1"], LogLik=AICTable$LL[AICTable$Modnames=="1"], NagR2=NagelkerkeR2(LinearDist_Model)$R2)) 
  Water <- rbind(Water, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="2"], LogLik=AICTable$LL[AICTable$Modnames=="2"], NagR2=NagelkerkeR2(WaterFeat_Model)$R2)) 
  Terrain <- rbind(Terrain, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="3"], LogLik=AICTable$LL[AICTable$Modnames=="3"], NagR2=NagelkerkeR2(Terrain_Model)$R2)) 
  Road <- rbind(Road, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="4"], LogLik=AICTable$LL[AICTable$Modnames=="4"], NagR2=NagelkerkeR2(Road_Model)$R2)) 
  Mitigation <- rbind(Mitigation, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="5"], LogLik=AICTable$LL[AICTable$Modnames=="5"], NagR2=NagelkerkeR2(Mitigation_Model)$R2)) 
  MooseDen <- rbind(MooseDen, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="6"], LogLik=AICTable$LL[AICTable$Modnames=="6"], NagR2=NagelkerkeR2(MooseDensity_Model)$R2)) 
  LinearDens <- rbind(LinearDens, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="7"], LogLik=AICTable$LL[AICTable$Modnames=="7"], NagR2=NagelkerkeR2(LinearDens_Model)$R2)) 
  VegComp <- rbind(VegComp, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="8"], LogLik=AICTable$LL[AICTable$Modnames=="8"], NagR2=NagelkerkeR2(Comp5471_Model)$R2)) 
  Human <- rbind(Human, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="9"], LogLik=AICTable$LL[AICTable$Modnames=="9"], NagR2=NagelkerkeR2(Human_Model)$R2)) 
  BioPhys <- rbind(BioPhys, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="10"], LogLik=AICTable$LL[AICTable$Modnames=="10"], NagR2=NagelkerkeR2(BioPhys_Model)$R2)) 
  Intercept <- rbind(Intercept, data.frame(iteration=i, Delta_AICc=AICTable$Delta_AICc[AICTable$Modnames=="11"], LogLik=AICTable$LL[AICTable$Modnames=="11"], NagR2=NagelkerkeR2(Null_Model)$R2)) 
  
  GLM_HUMAN <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet)
  GLM_HUMAN_TABLE <- rbind(GLM_HUMAN_TABLE, data.frame(iteration=i, Intercept_beta = GLM_HUMAN$coefficients[[1]], RdClassSEC_beta = GLM_HUMAN$coefficients[[2]], Sinuosity_beta = GLM_HUMAN$coefficients[[3]], DisDev_m_beta = GLM_HUMAN$coefficients[[4]], VegCutLocYES_beta = GLM_HUMAN$coefficients[[5]]))
  
  ## Mean parameter estimates and confidence intervals
  GLM_HUMAN_Intercept <- rbind(GLM_HUMAN_Intercept, data.frame(iteration = i, coefficient1 = GLM_HUMAN$coefficient[[1]]))
  GLM_HUMAN_RdClassSEC <- rbind(GLM_HUMAN_RdClassSEC, data.frame(iteration = i, coefficient2 = GLM_HUMAN$coefficient[[2]]))
  GLM_HUMAN_Sinuosity <- rbind(GLM_HUMAN_Sinuosity, data.frame(iteration = i, coefficient3 = GLM_HUMAN$coefficient[[3]]))
  GLM_HUMAN_DisDev_m <- rbind(GLM_HUMAN_DisDev_m, data.frame(iteration = i, coefficient4 = GLM_HUMAN$coefficient[[4]]))
  GLM_HUMAN_VegCutLocYES <- rbind(GLM_HUMAN_VegCutLocYES, data.frame(iteration = i, coefficient5 = GLM_HUMAN$coefficient[[5]]))
  
  print(i) 
} 

## Process simulation data. I want to know the number of times each models is top model, so deltaAICc = 0.00000000 and number of times the model is AIC < 2 of top model. 
## AIC summary results - Table 4
Summary <- NULL 
Summary <- rbind(Summary, data.frame(Rank=c("top","<2", "MeanNagR2"), LinearDist=c(sum(LinearDist$Delta_AICc==0.00000000),sum(LinearDist$Delta_AICc<2.0), mean(LinearDist$NagR2)), Water=c(sum(Water$Delta_AICc==0.00000000),sum(Water$Delta_AICc<2.0), mean(Water$NagR2)),Terrain=c(sum(Terrain$Delta_AICc==0.00000000),sum(Terrain$Delta_AICc<2.0), mean(Terrain$NagR2)), Road=c(sum(Road$Delta_AICc==0.00000000),sum(Road$Delta_AICc<2.0), mean(Road$NagR2)), Mitigation=c(sum(Mitigation$Delta_AICc==0.00000000),sum(Mitigation$Delta_AICc<2.0), mean(Mitigation$NagR2)), MooseDen=c(sum(MooseDen$Delta_AICc==0.00000000),sum(MooseDen$Delta_AICc<2.0), mean(MooseDen$NagR2)), LinearDens=c(sum(LinearDens$Delta_AICc==0.00000000),sum(LinearDens$Delta_AICc<2.0), mean(LinearDens$NagR2)),VegComp=c(sum(VegComp$Delta_AICc==0.00000000),sum(VegComp$Delta_AICc<2.0), mean(VegComp$NagR2)), Human=c(sum(Human$Delta_AICc==0.00000000),sum(Human$Delta_AICc<2.0), mean(Human$NagR2)), BioPhys=c(sum(BioPhys$Delta_AICc==0.00000000),sum(BioPhys$Delta_AICc<2.0), mean(BioPhys$NagR2)), Intercept=c(sum(Intercept$Delta_AICc==0.00000000),sum(Intercept$Delta_AICc<2.0), mean(Intercept$NagR2))))
print(Summary)

## Parameter estimates and confidence intervals - Table 3
## Mean parameter estimates
mean(GLM_HUMAN_Intercept$coefficient1)
mean(GLM_HUMAN_RdClassSEC$coefficient2)
mean(GLM_HUMAN_Sinuosity$coefficient3)
mean(GLM_HUMAN_DisDev_m$coefficient4)
mean(GLM_HUMAN_VegCutLocYES$coefficient5)

## 90% Confidence Intervals 
GLM_HUMAN_Intercept_Sort <- GLM_HUMAN_Intercept[order(GLM_HUMAN_Intercept$coefficient1),]
GLM_HUMAN_RdClassSEC_Sort <- GLM_HUMAN_RdClassSEC[order(GLM_HUMAN_RdClassSEC$coefficient2),]
GLM_HUMAN_Sinuosity_Sort <- GLM_HUMAN_Sinuosity[order(GLM_HUMAN_Sinuosity$coefficient3),]
GLM_HUMAN_DisDev_m_Sort <- GLM_HUMAN_DisDev_m[order(GLM_HUMAN_DisDev_m$coefficient4),]
GLM_HUMAN_VegCutLocYES_Sort <- GLM_HUMAN_VegCutLocYES[order(GLM_HUMAN_VegCutLocYES$coefficient5),]

print(GLM_HUMAN_Intercept_Sort)
print(GLM_HUMAN_RdClassSEC_Sort)
print(GLM_HUMAN_Sinuosity_Sort)
print(GLM_HUMAN_DisDev_m_Sort)
print(GLM_HUMAN_VegCutLocYES_Sort)

#################################################################
## To run a random model to compare cross-validation.
## Fit models 
LinearDist_M <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvailSet) 
summary(LinearDist_M)
WaterFeat_M <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
summary(WaterFeat_M)
Terrain_M <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvailSet) 
summary(Terrain_M)
Road_M <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvailSet) 
summary(Road_M)
Mitigation_M <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
summary(Mitigation_M)
MooseDensity_M <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvailSet) 
summary(MooseDensity_M)
LinearDen_M <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvailSet) 
summary(LinearDen_M)
Comp5471_M <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvailSet) 
summary(Comp5471_M)
Human_M <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvailSet) 
summary(Human_M)
BioPhys_M <- glm(Rand_MVC~MooseDen + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvailSet) 
summary(BioPhys_M)
Null_M <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvailSet) 
summary(Null_M)

## Make some diagnostic plots of your model to assess fit
par(mfrow=c(2,3))
par(mai=c(0.8,0.85,0.15,0.1))
plot(LinearDist_M)
hist(resid(LinearDist_M))

plot(WaterFeat_M)
hist(resid(WaterFeat_M))

plot(Terrain_M)
hist(resid(Terrain_M))

plot(Road_M)
hist(resid(Road_M))

plot(Mitigation_M)
hist(resid(Mitigation_M))

plot(MooseDensity_M)
hist(resid(MooseDensity_M))

plot(LinearDen_M)
hist(resid(LinearDen_M))

plot(Comp5471_M)
hist(resid(Comp5471_M))

plot(Human_M)
hist(resid(Human_M))

plot(BioPhys_M)
hist(resid(BioPhys_M))

#################################################################
## k-fold cross validation for TRUE models
## Adjusted cross-validation estimate of error with cost function included
## The response variable is binary variable therefore the cost function below was applied
## Table 5 - mean prediction error column
library(boot)
cost <- function(r, pi = 0) mean(abs(r-pi) > 0.5)
cv.glm(data=PresAvailSet, glmfit=LinearDist_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=WaterFeat_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Terrain_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Road_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Mitigation_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=MooseDensity_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=LinearDen_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Comp5471_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Human_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=BioPhys_M, cost, K=10)
cv.glm(data=PresAvailSet, glmfit=Null_M, cost, K=10)

#################################################################
## Cross-validation error is a relative measure therefore we need to generate random models so that we can compare cross validation of the "TRUE" model to the "RANDOM" models
## k-fold cross validation for RANDOM models
## Random models are created by re-shuffling random data, fitting models, then calculating cv.glm

LinearDist_Rand_Output <- NULL
WaterFeat_Rand_Output <- NULL
Terrain_Rand_Output <- NULL
Road_Rand_Output <- NULL
Mitigation_Rand_Output <- NULL
MooseDensity_Rand_Output <- NULL
LinearDen_Rand_Output <- NULL
Comp5471_Rand_Output <- NULL
Human_Rand_Output <- NULL
BioPhys_Rand_Output <- NULL
Null_Rand_Output <- NULL

## Randomly take X rows from the data set without replacement, where X is equal to the number of presence points for MVCs.
## This is where you take 600 points from the 1200. 
Random_PtsNew <- spatialallrandom[sample(nrow(spatialallrandom), 600),] 
## Step 2: Combine the data 
## Combine with presence data to make file for model fitting 
PresAvailSet2 <- rbind(Random_PtsNew, spatialallmvc) 

## Do it 100 times
for(x in seq(1,100,1)){
  
  ## Step 1 - Re-shuffle the response
  ## Reshuffle data and place in new file
  PresAvail_Shuf <- PresAvailSet2
  
  ## We are shuffling the second column as this is the column that indicates MVC or random point
  PresAvail_Shuf[,2] <-sample(PresAvail_Shuf[,2])
  
  ## Step 2
  ## Run the model
  LinearDist_Rand <- glm(Rand_MVC~DisLinFeaShort_m, family=binomial(link="logit"), data=PresAvail_Shuf) 
  WaterFeat_Rand <- glm(Rand_MVC~DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Terrain_Rand <- glm(Rand_MVC~TerrRugg5471, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Road_Rand <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Mitigation_Rand <- glm(Rand_MVC~VegCtLoc, family=binomial(link="logit"), data=PresAvail_Shuf) 
  MooseDensity_Rand <- glm(Rand_MVC~MooseDen, family=binomial(link="logit"), data=PresAvail_Shuf) 
  LinearDen_Rand <- glm(Rand_MVC~DenLinFea5471, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Comp5471_Rand <- glm(Rand_MVC~PropDecidConif5471, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Human_Rand <- glm(Rand_MVC~RdClass + Sinuosity + DisDev_m + VegCtLoc, family=binomial(link="logit"), data=PresAvail_Shuf) 
  BioPhys_Rand <- glm(Rand_MVC~MooseDen + DisOcn_m + DisFreshWaterShort_m, family=binomial(link="logit"), data=PresAvail_Shuf) 
  Null_Rand <- glm(Rand_MVC~1, family=binomial(link="logit"), data=PresAvail_Shuf) 
  
  ## Step 3
  ## Run cross validation
  ## Adjusted cross-validation estimate of error with cost function included
  ## The response variable is binary variable therefore the cost function below was applied
  library(boot)
  cost <- function(r, pi = 0) mean(abs(r-pi) > 0.5)
  cv1 <-cv.glm(data=PresAvail_Shuf, glmfit=LinearDist_Rand, cost, K=10)
  cv2 <-cv.glm(data=PresAvail_Shuf, glmfit=WaterFeat_Rand, cost, K=10)
  cv3 <-cv.glm(data=PresAvail_Shuf, glmfit=Terrain_Rand, cost, K=10)
  cv4 <-cv.glm(data=PresAvail_Shuf, glmfit=Road_Rand, cost, K=10)
  cv5 <-cv.glm(data=PresAvail_Shuf, glmfit=Mitigation_Rand, cost, K=10)
  cv6 <-cv.glm(data=PresAvail_Shuf, glmfit=MooseDensity_Rand, cost, K=10)
  cv7 <-cv.glm(data=PresAvail_Shuf, glmfit=LinearDen_Rand, cost, K=10)
  cv8 <-cv.glm(data=PresAvail_Shuf, glmfit=Comp5471_Rand, cost, K=10)
  cv9 <-cv.glm(data=PresAvail_Shuf, glmfit=Human_Rand, cost, K=10)
  cv10 <-cv.glm(data=PresAvail_Shuf, glmfit=BioPhys_Rand, cost, K=10)
  cv11 <-cv.glm(data=PresAvail_Shuf, glmfit=Null_Rand, cost, K=10)
  
  ## Step 4
  ## Collect the cv values for each model. For each iteration x save the cv.
  LinearDist_Rand_Output <- rbind(LinearDist_Rand_Output, data.frame(Iteration = x, CV1 = cv1$delta[2]))
  WaterFeat_Rand_Output <- rbind(WaterFeat_Rand_Output, data.frame(Iteration = x, CV2 = cv2$delta[2]))
  Terrain_Rand_Output <- rbind(Terrain_Rand_Output, data.frame(Iteration = x, CV3 = cv3$delta[2]))
  Road_Rand_Output <- rbind(Road_Rand_Output, data.frame(Iteration = x, CV4 = cv4$delta[2]))
  Mitigation_Rand_Output <- rbind(Mitigation_Rand_Output, data.frame(Iteration = x, CV5 = cv5$delta[2]))
  MooseDensity_Rand_Output <- rbind(MooseDensity_Rand_Output, data.frame(Iteration = x, CV6 = cv6$delta[2]))
  LinearDen_Rand_Output <- rbind(LinearDen_Rand_Output, data.frame(Iteration = x, CV7 = cv7$delta[2]))
  Comp5471_Rand_Output <- rbind(Comp5471_Rand_Output, data.frame(Iteration = x, CV8 = cv8$delta[2]))
  Human_Rand_Output <- rbind(Human_Rand_Output, data.frame(Iteration = x, CV9 = cv9$delta[2]))
  BioPhys_Rand_Output <- rbind(BioPhys_Rand_Output, data.frame(Iteration = x, CV10 = cv10$delta[2]))
  Null_Rand_Output <- rbind(Null_Rand_Output, data.frame(Iteration = x, CV11 = cv11$delta[2]))
  print (x)
}

## Step 5 - Table 5 confidence interval column 
## Sort random set to calculate 90% CI 
LinearDist_Rand_Output_Sort <- LinearDist_Rand_Output[order(LinearDist_Rand_Output$CV1),]
WaterFeat_Rand_Output_Sort <- WaterFeat_Rand_Output[order(WaterFeat_Rand_Output$CV2),]
Terrain_Rand_Output_Sort <- Terrain_Rand_Output[order(Terrain_Rand_Output$CV3),]
Road_Rand_Output_Sort <- Road_Rand_Output[order(Road_Rand_Output$CV4),]
Mitigation_Rand_Output_Sort <- Mitigation_Rand_Output[order(Mitigation_Rand_Output$CV5),]
MooseDensity_Rand_Output_Sort <- MooseDensity_Rand_Output[order(MooseDensity_Rand_Output$CV6),]
LinearDen_Rand_Output_Sort <- LinearDen_Rand_Output[order(LinearDen_Rand_Output$CV7),]
Comp5471_Rand_Output_Sort <- Comp5471_Rand_Output[order(Comp5471_Rand_Output$CV8),]
Human_Rand_Output_Sort <- Human_Rand_Output[order(Human_Rand_Output$CV9),]
BioPhys_Rand_Output_Sort <- BioPhys_Rand_Output[order(BioPhys_Rand_Output$CV10),]
Null_Rand_Output_Sort <- Null_Rand_Output[order(Null_Rand_Output$CV11),]

print(LinearDist_Rand_Output_Sort)
print(WaterFeat_Rand_Output_Sort)
print(Terrain_Rand_Output_Sort)
print(Road_Rand_Output_Sort)
print(Mitigation_Rand_Output_Sort)
print(MooseDensity_Rand_Output_Sort)
print(LinearDen_Rand_Output_Sort)
print(Comp5471_Rand_Output_Sort)
print(Human_Rand_Output_Sort)
print(BioPhys_Rand_Output_Sort)
print(Null_Rand_Output_Sort)
